cms

package
v0.0.226 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 2, 2026 License: Apache-2.0 Imports: 13 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func GetEnumerateDrupalModuleEmbeddedPath added in v0.0.218

func GetEnumerateDrupalModuleEmbeddedPath(modulesFileSize enumeratecmsdrupalfern.ModulesFileSize) string

GetEnumerateDrupalModuleEmbeddedPath returns the embedded config path for the given module file size.

func GetEnumerateWordpressPluginEmbeddedPath added in v0.0.218

func GetEnumerateWordpressPluginEmbeddedPath(PluginsFileSize enumeratecmswordpressfern.PluginsFileSize) string

GetEnumerateWordpressPluginEmbeddedPath returns the embedded config path for the given plugin file size.

func PerformAppEnumerateCMSDrupalModules added in v0.0.215

PerformAppEnumerateCMSDrupalModules attempts to find modules installed on Drupal sites.

func PerformAppEnumerateCMSWordpressPlugins

PerformAppEnumerateCMSWordpressPlugins attempts to find plugins installed on WordPress sites. It returns a report containing the results for each target and any errors encountered.

Types

This section is empty.

Jump to